@@ -1,6 +1,6 @@
 """This module contains the main part of Instant, the build_module function."""
 
-import os, sys, shutil, glob
+import os, sys, shutil, glob, errno
 from itertools import chain
 
 # TODO: Import only the official interface
@@ -35,6 +35,16 @@ def arg_strings(x):
         x = x.split()
     return strip_strings(x)
 
+def makedirs(path):
+    """
+    Creates a directory (tree). If directory already excists it does nothing.
+    """
+    try:
+        os.makedirs(path)
+    except os.error, e:
+        if e.errno != errno.EEXIST:
+            raise
+
 def copy_files(source, dest, files):
     """Copy a list of files from a source directory to a destination directory.
     This may seem a bit complicated, but a lot of this code is error checking."""
@@ -44,7 +54,7 @@ def copy_files(source, dest, files):
             instant_warning("In instant.copy_files: Path '%s' already exists, "\
                 "overwriting existing files: %r." % (dest, list(overwriting)))
     else:
-        os.mkdir(dest)
+        makedirs(dest)
     
     if source != dest:
         instant_debug("In instant.copy_files: Copying files %r from %r to %r"\
@@ -84,7 +94,11 @@ def recompile(modulename, module_path, setup_name, new_compilation_checksum):
     
     # Create log file for logging of compilation errors
     compile_log_filename = os.path.join(module_path, "compile.log")
+    compile_log_filename_dest = os.path.join(get_default_error_dir(), \
+                                             modulename, "compile.log")
     compile_log_file = open(compile_log_filename, "w")
+
+    ret = 1
     try:
         # Build module
         cmd = "python %s build_ext install --install-platlib=." % setup_name
@@ -96,15 +110,28 @@ def recompile(modulename, module_path, setup_name, new_compilation_checksum):
         if ret != 0:
             if os.path.exists(compilation_checksum_filename):
                 os.remove(compilation_checksum_filename)
+            
             instant_error("In instant.recompile: The module did not "\
-                "compile, see '%s'" % compile_log_filename)
+                "compile, see '%s'" % compile_log_filename_dest)
     finally:
         compile_log_file.close()
+        if ret != 0:
+            if "INSTANT_DISPLAY_COMPILE_LOG" in os.environ.keys():
+                instant_warning("")
+                instant_warning("Content of instant compile.log")
+                instant_warning("==============================")
+                instant_warning(output)
+                instant_warning("")
+            
+            # Copy module to error dir
+            module_path = copy_to_cache(module_path, get_default_error_dir(),\
+                                        modulename, check_for_existing_path=False)
     
     # Compilation succeeded, write new_compilation_checksum to checksum_file
     write_file(compilation_checksum_filename, new_compilation_checksum)
 
-def copy_to_cache(module_path, cache_dir, modulename):
+def copy_to_cache(module_path, cache_dir, modulename, \
+                  check_for_existing_path=True):
     "Copy module directory to cache."
     # Get lock, check if the module exists, _otherwise_ copy the
     # finished compiled module from /tmp/foo to the cache directory,
@@ -113,7 +140,7 @@ def copy_to_cache(module_path, cache_dir, modulename):
 
     # Validate the path
     cache_module_path = os.path.join(cache_dir, modulename)
-    if os.path.exists(cache_module_path):
+    if check_for_existing_path and os.path.exists(cache_module_path):
         # This indicates a race condition has happened (and is being avoided!).
         instant_warning("In instant.build_module: Path '%s' already exists,"\
             " but module wasn't found in cache previously. Not overwriting,"\
@@ -127,17 +154,23 @@ def copy_to_cache(module_path, cache_dir, modulename):
     
     # Error checks
     instant_assert(os.path.isdir(module_path), "In instant.build_module:"\
-        " Cannot copy non-existing directory %r!" % module_path)
-    instant_assert(not os.path.isdir(cache_module_path),
-        "In instant.build_module: Cache directory %r shouldn't exist "\
-        "at this point!" % cache_module_path)
+                   " Cannot copy non-existing directory %r!" % module_path)
+    if check_for_existing_path and os.path.isdir(cache_module_path):
+        instant_error("In instant.build_module: Cache directory %r shouldn't"\
+                      " exist at this point!" % cache_module_path)
     instant_debug("In instant.build_module: Copying built module from %r"\
         " to cache at %r" % (module_path, cache_module_path))
     
     # Do the copying
-    shutil.copytree(module_path, cache_module_path)
-    delete_temp_dir()
-    release_lock(lock)
+    try:
+        shutil.copytree(module_path, cache_module_path)
+    except OSError, e:
+        if e.errno != errno.EEXIST:
+            raise
+    finally:
+        delete_temp_dir()
+        release_lock(lock)
+    
     return cache_module_path
 
 def build_module(modulename=None, source_directory=".",
@@ -374,14 +407,13 @@ def build_module(modulename=None, source_directory=".",
         instant_assert(not os.path.exists(module_path),
             "In instant.build_module: Not expecting module_path to exist: '%s'"\
             % module_path)
-        os.mkdir(module_path)
+        makedirs(module_path)
         use_cache = True
     else:
         use_cache = False
         moduleids = []
         module_path = os.path.join(original_path, modulename)
-        if not os.path.exists(module_path):
-            os.mkdir(module_path)
+        makedirs(module_path)
         
         ## Look for module in memory cache
         #module, moduleids = check_memory_cache(modulename)
@@ -497,7 +529,7 @@ def build_module_vtk(c_code, cache_dir=None):
     module_path = os.path.join(get_temp_dir(), modulename)
 
 
-    os.mkdir(module_path)
+    makedirs(module_path)
     os.chdir(module_path)
 
     write_cmakefile(modulename)
@@ -525,8 +557,7 @@ def build_module_vmtk(c_code, cache_dir=None):
     moduleids = [signature]
     module_path = os.path.join(get_temp_dir(), modulename)
 
-
-    os.mkdir(module_path)
+    makedirs(module_path)
     os.chdir(module_path)
 
     write_vmtk_cmakefile(modulename)
