@@ -1,7 +1,7 @@
 """This module contains the inline* functions, which allows easy inlining of C/C++ functions."""
 
 from output import instant_assert, instant_warning, instant_error
-from build import build_module
+from build import build_module, build_module_vtk, build_module_vmtk
 
 
 def get_func_name(c_code):
@@ -14,6 +14,7 @@ def get_func_name(c_code):
     return func_name
 
 
+
 def inline(c_code, **kwargs):
     """This is a short wrapper around the build_module function in instant. 
     
@@ -133,3 +134,25 @@ def inline_module_with_numpy(c_code, **kwargs):
     kwargs["include_dirs"]   = kwargs.get("include_dirs",[])   + ["%s" % numpy.get_include()]
     module = build_module(**kwargs)
     return module
+
+
+def inline_vtk(c_code, cache_dir=None): 
+
+    module = build_module_vtk(c_code)
+    func_name = get_func_name(c_code)
+    if hasattr(module, func_name):
+        return getattr(module, func_name)
+    else:
+        instant_warning("Didn't find function '%s', returning module." % func_name)
+    return module
+
+def inline_vmtk(c_code, cache_dir=None): 
+
+    module = build_module_vmtk(c_code)
+    func_name = get_func_name(c_code)
+    if hasattr(module, func_name):
+        return getattr(module, func_name)
+    else:
+        instant_warning("Didn't find function '%s', returning module." % func_name)
+    return module
+
